#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['csp_helpers', 'csp_helpers.templatetags']

package_data = \
{'': ['*']}

install_requires = \
['django>=2.2']

setup(name='django-csp-helpers',
      version='0.6.0',
      description='A set of template tags (and mixins!) to assist in building CSP-enabled websites.',
      author='Luke Rogers',
      author_email='luke@dmptr.com',
      url='https://github.com/dmptrluke/django-csp-helpers',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      python_requires='>=3.6',
     )
